FlutterInspectorDioInterceptor class
A Dio interceptor that automatically records requests and responses to the FlutterInspector.
Constructors
- FlutterInspectorDioInterceptor(FlutterInspector _inspector, {Dio? sourceDio})
-
Creates the interceptor, feeding entries to the provided
_inspector.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceDio → Dio?
-
Optional
Dioinstance that originated this request (e.g. for replay).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
DioException err, ErrorInterceptorHandler handler) → void - Called when an exception was occurred during the request.
-
onRequest(
RequestOptions options, RequestInterceptorHandler handler) → void - Called when the request is about to be sent.
-
onResponse(
Response response, ResponseInterceptorHandler handler) → void - Called when the response is about to be resolved.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited